@@ -16,6 +16,7 @@
 from twisted.trial import unittest
 from elisa.core.tests.elisa_test_case import ElisaTestCase
 
+import tempfile
 import os
 from elisa.core import config
 from elisa.core import log
@@ -141,3 +142,16 @@ foo=['bar'
         for opt_name in  self.test_section_dict.keys():
             c.del_option(opt_name,'tests')
             self.assertEqual(c.get_option(opt_name,'tests'), None)
+
+    def test_get_config_dir(self):
+        c = self.load_config()
+        self.assertEqual(c.get_config_dir(), os.getcwd())
+
+        fd, filename = tempfile.mkstemp()
+        tmp_config = config.Config(self.test_conf)
+        tmp_config.write(filename)
+
+        cfg = config.Config(filename)
+        self.assertEqual(cfg.get_config_dir(), tempfile.gettempdir())
+
+        os.unlink(filename)
